cheesecake.codeparser.CodeParser

Package cheesecake :: Module codeparser :: Class CodeParser |
[show private | hide private]
[frames | no frames]

## Type CodeParser

    object --+
             |
            CodeParser

Information about the structure of a Python module.

- Collects modules, classes, methods, functions and associated docstrings
- Based on mwh's docextractor.model module

Method Summary
| ``__init__`(self, pyfile, log)` Initialize Code Parser object.
| ``docstring_count`(self)` Return number of docstrings found in this module.
| ``docstring_count_by_type`(self, type)` Return number of docstrings of given type found in this module.
| ``object_count`(self)` Return number of objects found in this module.
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Property Summary
| `functions_called`

Method Details

### __init__(self, pyfile, log=None) (Constructor) Initialize Code Parser object. Overrides: `__builtin__.object.__init__` Parameters: `pyfile` : str Path to a Python module to parse. `log` : logger.Producer instance Logger to use during code parsing.

### docstring_count(self) Return number of docstrings found in this module.

### docstring_count_by_type(self, type) Return number of docstrings of given type found in this module.

### object_count(self) Return number of objects found in this module. Objects include: * module * classes * methods * functions

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net